@@ -1,6 +1,4 @@
-use crate::headers::*;
-use crate::AddAsHeader;
-use http::request::Builder;
+use crate::headers::{self, Header};
 use std::str::FromStr;
 use uuid::Uuid;
 
@@ -21,8 +19,12 @@ impl std::str::FromStr for LeaseId {
     }
 }
 
-impl AddAsHeader for LeaseId {
-    fn add_as_header(&self, builder: Builder) -> Builder {
-        builder.header(LEASE_ID, &format!("{}", self.0))
+impl Header for LeaseId {
+    fn name(&self) -> headers::HeaderName {
+        headers::LEASE_ID.into()
+    }
+
+    fn value(&self) -> headers::HeaderValue {
+        format!("{}", self.0).into()
     }
 }
