@@ -1,5 +1,9 @@
+mod accept;
+mod accept_encoding;
 mod activity_id;
+mod app;
 mod client_request_id;
+mod client_version;
 mod content_disposition;
 mod content_encoding;
 mod content_language;
@@ -27,10 +31,16 @@ mod sequence_number;
 mod sequence_number_condition;
 mod source_lease_id;
 mod timeout;
+mod user;
 mod user_agent;
+mod version;
 
+pub use accept::Accept;
+pub use accept_encoding::AcceptEncoding;
 pub use activity_id::ActivityId;
+pub use app::App;
 pub use client_request_id::ClientRequestId;
+pub use client_version::ClientVersion;
 pub use content_disposition::ContentDisposition;
 pub use content_encoding::ContentEncoding;
 pub use content_language::ContentLanguage;
@@ -58,4 +68,6 @@ pub use sequence_number::SequenceNumber;
 pub use sequence_number_condition::SequenceNumberCondition;
 pub use source_lease_id::SourceLeaseId;
 pub use timeout::Timeout;
+pub use user::User;
 pub use user_agent::UserAgent;
+pub use version::Version;
