@@ -1,5 +1,4 @@
-use crate::AddAsHeader;
-use http::request::Builder;
+use crate::headers::{self, Header};
 
 #[derive(Debug, Clone, Copy, PartialEq, PartialOrd, Eq, Ord)]
 pub struct SequenceNumber(u64);
@@ -10,14 +9,18 @@ impl SequenceNumber {
     }
 }
 
-impl AddAsHeader for SequenceNumber {
-    fn add_as_header(&self, builder: Builder) -> Builder {
-        builder.header(crate::BLOB_SEQUENCE_NUMBER, &format!("{}", self.0))
-    }
-}
-
 impl From<u64> for SequenceNumber {
     fn from(max_results: u64) -> Self {
         Self::new(max_results)
     }
 }
+
+impl Header for SequenceNumber {
+    fn name(&self) -> headers::HeaderName {
+        headers::BLOB_SEQUENCE_NUMBER.into()
+    }
+
+    fn value(&self) -> headers::HeaderValue {
+        self.0.to_string().into()
+    }
+}
