@@ -1,6 +1,4 @@
-use crate::headers::*;
-use crate::AddAsHeader;
-use http::request::Builder;
+use crate::headers::{self, Header};
 use std::str::FromStr;
 use uuid::Uuid;
 
@@ -21,8 +19,12 @@ impl std::str::FromStr for SourceLeaseId {
     }
 }
 
-impl AddAsHeader for SourceLeaseId {
-    fn add_as_header(&self, builder: Builder) -> Builder {
-        builder.header(SOURCE_LEASE_ID, &format!("{}", self.0))
+impl Header for SourceLeaseId {
+    fn name(&self) -> headers::HeaderName {
+        headers::SOURCE_LEASE_ID.into()
+    }
+
+    fn value(&self) -> headers::HeaderValue {
+        self.0.to_string().into()
     }
 }
